#[repr(C)]pub struct dv_inference_queue_statistics {
pub occupancy_count: c_int,
pub length: c_int,
pub wait_time: f32,
}Fields
occupancy_count: c_int< Number of inference queue slots occupied with inference request for the endpoint
length: c_int< length of the inference queue for the endpoint
wait_time: f32< waiting time in mili secs for the new inference request to get picked up by endpoint